@@ -27,8 +27,7 @@ import abc
 import argparse
 import json
 import logging
-
-
+from pathlib import Path
 from time import sleep
 
 import psycopg2 as pg
@@ -79,7 +78,7 @@ def good_db_status() -> tuple:
             pg.extensions.TRANSACTION_STATUS_INTRANS)
 
 
-def read_cfg(cfg_file, section, prefer_cfg=False) -> dict:
+def read_cfg(cfg_file, section: str, prefer_cfg: bool = False) -> dict:
     """Read the config file and return the result of one section."""
     try:
         file_content = read_yml_or_cfg(cfg_file, prefer_cfg=prefer_cfg)
@@ -93,10 +92,12 @@ def read_cfg(cfg_file, section, prefer_cfg=False) -> dict:
     return content
 
 
-def db_config(filename='database.ini', section='postgresql') -> dict:
+def db_config(filename: str = 'database.ini',
+              section: str = 'postgresql') -> dict:
     """Return the database config as JSON"""
-    LOGGER.info("Read db_config['%s'] from '%s'", section, filename)
-    cfg = read_cfg(filename, section)
+    file = Path(__file__).parent / filename
+    LOGGER.info("Read db_config['%s'] from '%s'", section, file.resolve())
+    cfg = read_cfg(file, section)
     return {**DEFAULT_DBCONFIG, **cfg}
 
 
@@ -201,7 +202,6 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
         timeline = self.read_timeline(edgearray)
 
         return {'incidenceGraph': incidence_graph,
-                'generalGraph': False,
                 'tdTimeline': timeline,
                 'treeDecJson': tree_dec_json}
 
@@ -359,7 +359,7 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
             return result
 
     @staticmethod
-    def footer(lines):
+    def footer(lines) -> str:
         """Returns the footer for solution bags."""
         return "sum: " + str(sum([li[-1] for li in lines]))
 
@@ -369,7 +369,7 @@ class DpdbSatVisu(DpdbSharpSatVisu):
     Removing the solution sum in bottom-label.
     """
     @staticmethod
-    def footer(lines):
+    def footer(lines) -> str:
         """Returns empty footer."""
         return ""
 
@@ -387,11 +387,11 @@ class DpdbMinVcVisu(DpdbSharpSatVisu):
             " can not read_clauses!")
 
     @staticmethod
-    def footer(lines):
+    def footer(lines) -> str:
         """Returns the footer for solution bags."""
         return "min-size: " + str(min([li[-1] for li in lines]))
 
-    def read_twfile(self):
+    def read_twfile(self) -> list:
         """
         Use TwReader.from_file to read the edges for the generalGraph.
 
@@ -411,7 +411,7 @@ class DpdbMinVcVisu(DpdbSharpSatVisu):
         # create list so that it is JSON serializable
         return list(reader.edges)
 
-    def construct(self):
+    def construct(self) -> dict:
         """
         Construct the Json calling several helper methods.
 
@@ -433,8 +433,7 @@ class DpdbMinVcVisu(DpdbSharpSatVisu):
         general_gr = {'edges': self.read_twfile()} if self.tw_file else False
 
         timeline = self.read_timeline(edgearray)
-        return {'incidenceGraph': False,
-                'generalGraph': general_gr,
+        return {'generalGraph': general_gr,
                 'tdTimeline': timeline,
                 'treeDecJson': tree_dec_json}
 
@@ -461,7 +460,10 @@ def connect() -> pg.extensions.connection:
     return conn
 
 
-def create_json(problem: int, tw_file=None, intermed_nodes=False) -> dict:
+def create_json(
+        problem: int,
+        tw_file=None,
+        intermed_nodes: bool = False) -> dict:
     """Create the JSON for the specified problem instance."""
 
     try:
@@ -509,14 +511,7 @@ def main(args: argparse.Namespace) -> None:
     None
     """
 
-    loglevel = None  # passed to the configuration of the root-logger
-    if args.loglevel is not None:
-        try:
-            loglevel = int(float(args.loglevel))
-        except ValueError:
-            loglevel = args.loglevel.upper()
-    logging.basicConfig(level=loglevel)  # Output logging for setup
-    logging_cfg(filename='logging.yml', loglevel=loglevel)
+    logging_cfg(filename='logging.yml', loglevel=args.loglevel)
     LOGGER.info("Called with '%s'", args)
 
     problem_ = args.problemnumber
