@@ -32,8 +32,9 @@ import itertools
 import json
 import logging
 from dataclasses import asdict
+from pathlib import Path
 from sys import stdin
-from typing import List, Optional
+from typing import Iterable, List, Optional, Union, NewType
 
 from graphviz import Digraph, Graph
 from tdvisu.visualization_data import (VisualizationData, IncidenceGraphData,
@@ -47,8 +48,10 @@ from tdvisu.utilities import style_hide_edge, style_hide_node, emphasise_node
 
 LOGGER = logging.getLogger('visualization.py')
 
+StrOrIo = NewType('StrOrIo', Union[str, io.TextIOWrapper])
 
-def read_json(json_data) -> dict:
+
+def read_json(json_data: StrOrIo) -> dict:
     """
     Read json data into a callable object.
     Throws AssertionError if the parsed object has length 0.
@@ -81,42 +84,39 @@ class Visualization:
     of dynamic programming on tree decomposition.
     """
 
-    def __init__(self, infile, outfolder) -> None:
+    def __init__(self, infile: StrOrIo, outfolder: Path):
         """Copy needed fields from arguments and create VisualizationData."""
         self.data: VisualizationData = self.inspect_json(infile)
-        self.outfolder = outfolder
-
+        self.outfolder = Path(outfolder).resolve()
         self.tree_dec_digraph = None
         LOGGER.debug("Initialized: %s", self)
-        # LOGGER.debug("self.__dict__:%s", self.__dict__)
-        # LOGGER.debug("self.data.svg_join:%s", self.data.svg_join)
 
-    def inspect_json(self, infile) -> VisualizationData:
+    def inspect_json(self, infile: StrOrIo) -> VisualizationData:
         """Read and preprocess the needed data from the infile into VisualizationData."""
         LOGGER.debug("Reading from: %s", infile)
         visudata = read_json(infile)
         LOGGER.debug("Found keys: %s", visudata.keys())
 
         try:
-            _incid = visudata['incidenceGraph']
-            _general_graph = visudata['generalGraph']
-            _svg_join = visudata.get('svg_join', None)
+            _incid = visudata.get('incidenceGraph', None)
+            _general_graph = visudata.get('generalGraph', None)
+            _svg_join = visudata.get('svgjoin', None)
 
-            incid_data: IncidenceGraphData = None
+            incid_data: Optional[IncidenceGraphData] = None
             if _incid:
                 _incid['edges'] = [[x['id'], x['list']]
                                    for x in _incid['edges']]
                 incid_data = IncidenceGraphData(**_incid)
             visudata.pop('incidenceGraph')
-            general_graph_data: GeneralGraphData = None
+            general_graph_data: Optional[GeneralGraphData] = None
             if _general_graph:
                 general_graph_data = GeneralGraphData(**_general_graph)
             visudata.pop('generalGraph')
-            svg_join_data: SvgJoinData = None
+            svg_join_data: Optional[SvgJoinData] = None
             if _svg_join:
                 svg_join_data = SvgJoinData(**_svg_join)
-            if 'svg_join' in visudata:
-                visudata.pop('svg_join')
+            if 'svgjoin' in visudata:
+                visudata.pop('svgjoin')
 
             self.timeline = visudata['tdTimeline']
             visudata.pop('tdTimeline')
@@ -135,11 +135,11 @@ class Visualization:
 
     def setup_tree_dec_graph(
             self,
-            rankdir='BT',
-            shape='box',
-            fillcolor='white',
-            style='rounded,filled',
-            margin='0.11,0.01') -> None:
+            rankdir: str = 'BT',
+            shape: str = 'box',
+            fillcolor: str = 'white',
+            style: str = 'rounded,filled',
+            margin: str = '0.11,0.01') -> None:
         """Create self.tree_dec_digraph
         strict means not a multigraph - equal edges get merged.
 
@@ -165,7 +165,11 @@ class Visualization:
         self.tree_dec_digraph.edges([(self.bagpre % str(first), self.bagpre % str(
             second)) for (first, second) in self.tree_dec['edgearray']])
 
-    def forward_iterate_tdg(self, joinpre, solpre, soljoinpre) -> None:
+    def forward_iterate_tdg(
+            self,
+            joinpre: str,
+            solpre: str,
+            soljoinpre: str) -> None:
         """Create the final positions of all nodes with solutions."""
         tdg = self.tree_dec_digraph                 # shorten name
 
@@ -207,12 +211,12 @@ class Visualization:
                     tdg.edge(joinpre % id_inv_bags, self.bagpre % suc
                              if isinstance(suc, int) else joinpre % suc)
 
-    def backwards_iterate_tdg(self, joinpre, solpre, soljoinpre,
-                              view=False) -> None:
+    def backwards_iterate_tdg(self, joinpre: str, solpre: str, soljoinpre: str,
+                              view: bool = False) -> None:
         """Cut the single steps back and update emphasis acordingly."""
         tdg = self.tree_dec_digraph     # shorten name
         last_sol = ""
-
+        _filename = self.outfolder / self.data.td_file
         for i, node in enumerate(reversed(self.timeline)):
             id_inv_bags = node[0]
             LOGGER.debug("%s: Reverse traversing on %s", i, id_inv_bags)
@@ -249,12 +253,13 @@ class Visualization:
                                id_inv_bags,
                                int) else joinpre %
                            id_inv_bags)
-            _filename = self.outfolder + self.data.td_file + '%d'
-            tdg.render(
-                view=view, format='svg', filename=_filename %
-                (len(self.timeline) - i))
 
-    def tree_dec_timeline(self, view=False) -> None:
+            tdg.render(
+                view=view, format='svg',
+                filename=str(_filename) + str(len(self.timeline) - i)
+            )
+
+    def tree_dec_timeline(self, view: bool = False) -> None:
         """Main-method for handling all construction of the timeline."""
 
         self.setup_tree_dec_graph(
@@ -275,7 +280,7 @@ class Visualization:
 
         # Prepare supporting graph timeline
 
-        _timeline: List[Optional[object]] = []
+        _timeline: List[Optional[List[int]]] = []
         for step in self.timeline:
             if len(step) < 2:
                 _timeline.append(None)
@@ -356,23 +361,23 @@ class Visualization:
 
     def general_graph(
             self,
-            timeline,
-            edges,
-            extra_nodes=tuple(),
-            view=False,
-            fontsize='20',
-            fontcolor='black',
-            penwidth='2.2',
-            first_color='yellow',
-            first_style='filled',
-            second_color='green',
-            second_style='dotted,filled',
-            third_color='red',
-            graph_name='graph',
-            file_basename='graph',
-            do_sort_nodes=True,
-            do_adj_nodes=True,
-            var_name='') -> None:
+            timeline: Iterable[Optional[List[int]]],
+            edges: Iterable[Iterable[int]],
+            extra_nodes: Iterable[int] = tuple(),
+            view: bool = False,
+            fontsize: int = 20,
+            fontcolor: str = 'black',
+            penwidth: float = 2.2,
+            first_color: str = 'yellow',
+            first_style: str = 'filled',
+            second_color: str = 'green',
+            second_style: str = 'dotted,filled',
+            third_color: str = 'red',
+            graph_name: str = 'graph',
+            file_basename: str = 'graph',
+            do_sort_nodes: bool = True,
+            do_adj_nodes: bool = True,
+            var_name: str = '') -> None:
         """
         Creates one graph emphasized for the given timeline.
 
@@ -400,9 +405,9 @@ class Visualization:
         None, but outputs the files with the graph for each timestep.
 
         """
-        _filename = self.outfolder + file_basename + '%d'
+        _filename = self.outfolder / file_basename
         LOGGER.info("Generating general-graph for '%s'", file_basename)
-        vartag_n = var_name + '%d'
+        vartag_n: str = var_name + '%d'
         # sfdp http://yifanhu.net/SOFTWARE/SFDP/index.html
         default_engine = 'sfdp'
 
@@ -416,8 +421,8 @@ class Visualization:
                 'outputorder': 'edgesfirst',
                 'K': '2'},
             node_attr={
-                'fontcolor': fontcolor,
-                'penwidth': penwidth,
+                'fontcolor': str(fontcolor),
+                'penwidth': str(penwidth),
                 'style': 'filled',
                 'fillcolor': 'white'})
 
@@ -446,8 +451,8 @@ class Visualization:
 
         for (src, tar) in edges:
             graph.edge(vartag_n % src, vartag_n % tar)
-        for node in extra_nodes:
-            graph.node(vartag_n % node)
+        for nodeid in extra_nodes:
+            graph.node(vartag_n % nodeid)
 
         bodybaselen = len(graph.body)
 
@@ -459,7 +464,7 @@ class Visualization:
                 graph.render(
                     view=view,
                     format='svg',
-                    filename=_filename % i)
+                    filename=str(_filename) + str(i))
                 continue
 
             for var in variables:
@@ -470,12 +475,12 @@ class Visualization:
 
             # highlight edges between variables
             for (s, t) in edges:
-                if (s in variables and t in variables):
+                if s in variables and t in variables:
                     graph.edge(
                         vartag_n % s,
                         vartag_n % t,
                         color=third_color,
-                        penwidth=penwidth)
+                        penwidth=str(penwidth))
 
             if do_adj_nodes:
                 # set.difference accepts list as argument, "-" does not.
@@ -489,23 +494,24 @@ class Visualization:
                                color=second_color,
                                style=second_style)
 
-            graph.render(view=view, format='svg', filename=_filename % i)
+            graph.render(view=view, format='svg',
+                         filename=str(_filename) + str(i))
 
     def incidence(
             self,
-            timeline,
-            num_vars,
-            colors,
-            inc_file='IncidenceGraphStep',
-            view=False,
-            fontsize=16,
-            penwidth=2.2,
-            basefill='white',
-            sndshape='diamond',
-            neg_tail='odot',
-            var_name_one='',
-            var_name_two='',
-            column_distance=0.5) -> None:
+            timeline: Iterable[Optional[List[int]]],
+            num_vars: int,
+            colors: List,
+            inc_file: str = 'IncidenceGraphStep',
+            view: bool = False,
+            fontsize: Union[str, int] = 16,
+            penwidth: float = 2.2,
+            basefill: str = 'white',
+            sndshape: str = 'diamond',
+            neg_tail: str = 'odot',
+            var_name_one: str = '',
+            var_name_two: str = '',
+            column_distance: float = 0.5) -> None:
         """
         Creates the incidence graph emphasized for the given timeline.
 
@@ -540,7 +546,7 @@ class Visualization:
         None, but outputs the files with the graph for each timestep.
 
         """
-        _filename = self.outfolder + inc_file + '%d'
+        _filename = self.outfolder / inc_file
 
         clausetag_n = var_name_one + '%d'
         vartag_n = var_name_two + '%d'
@@ -607,7 +613,8 @@ class Visualization:
             # reset highlighting
             g_incid.body = g_incid.body[:bodybaselen]
             if variables is None:
-                g_incid.render(view=view, format='svg', filename=_filename % i)
+                g_incid.render(view=view, format='svg',
+                               filename=str(_filename) + str(i))
                 continue
 
             emp_clause = {
@@ -650,9 +657,12 @@ class Visualization:
                                  arrowtail='odot',
                                  style=_style)
 
-            g_incid.render(view=view, format='svg', filename=_filename % i)
+            g_incid.render(
+                view=view,
+                format='svg',
+                filename=str(_filename) + str(i))
 
-    def call_svgjoin(self):
+    def call_svgjoin(self) -> None:
         """Analyzes content in data.svg_join for the call to svg_join."""
         sj_data = self.data.svg_join
         if not sj_data.base_names:
@@ -685,23 +695,16 @@ def main(args: argparse.Namespace) -> None:
     -------
     None
     """
-    loglevel = None  # passed the configuration of the root-logger
-    if args.loglevel is not None:
-        try:
-            loglevel = int(float(args.loglevel))
-        except ValueError:
-            loglevel = args.loglevel.upper()
-    logging.basicConfig(level=loglevel)  # Output logging for setup
-    logging_cfg(filename='logging.yml', loglevel=loglevel)
+
+    logging_cfg(filename='logging.yml', loglevel=args.loglevel)
     LOGGER.info("Called with '%s'", args)
 
     infile = args.infile
     outfolder = args.outfolder
     if not outfolder:
         outfolder = 'outfolder'
-    outfolder = outfolder.replace('\\', '/')
-    if not outfolder.endswith('/'):
-        outfolder += '/'
+    outfolder = Path(outfolder).resolve()
+
     LOGGER.info("Will read from '%s' and write to folder '%s'",
                 infile.name, outfolder)
     visu = Visualization(infile=infile, outfolder=outfolder)
