@@ -54,7 +54,7 @@ class IncidenceGraphData:
     inc_file: str = 'IncidenceGraphStep'
     dual_file: str = 'DualGraphStep'
     fontsize: int = 16
-    penwidth: Union[float, str] = 2.2
+    penwidth: float = 2.2
     second_shape: str = 'diamond'
     column_distance: float = 0.5
 
@@ -76,6 +76,10 @@ class GeneralGraphData:
     second_style: str = 'dotted,filled'
     third_color: str = 'red'
 
+    def __post_init__(self):
+        if self.extra_nodes is None:
+            self.extra_nodes = list()
+
 
 @dataclass
 class VisualizationData:
